@@ -6,11 +6,11 @@ from emannotationschemas.schemas.synapse import BuhmannEcksteinSynapseSchema
 from emannotationschemas.schemas.synapse import NoCleftSynapse
 from emannotationschemas.schemas.bouton_shape import BoutonShape
 from emannotationschemas.schemas.presynaptic_bouton_type import PresynapticBoutonType
+from emannotationschemas.schemas.base import ReferenceAnnotation
 from emannotationschemas.schemas.functional_coregistration import (
     FunctionalCoregistration,
     FunctionalUnitCoregistration,
-    FunctionalUnitCoregistrationExtended,
-    FunctionalUnitCoregistrationQC,
+    FunctionalUnitCoregistrationExtended
 )
 from emannotationschemas.schemas.postsynaptic_compartment import PostsynapticCompartment
 from emannotationschemas.schemas.base import FlatSegmentationReferenceSinglePoint
@@ -47,7 +47,7 @@ from emannotationschemas.schemas.braincircuits import BrainCircuitsBoundTagAnnot
 from emannotationschemas.errors import UnknownAnnotationTypeException
 from emannotationschemas.flatten import create_flattened_schema
 
-__version__ = "5.2.0"
+__version__ = "5.5.0"
 
 type_mapping = {
     "synapse": SynapseSchema,
@@ -60,7 +60,7 @@ type_mapping = {
     "microns_func_coreg": FunctionalCoregistration,
     "microns_func_unit_coreg": FunctionalUnitCoregistration,
     "func_unit_ext_coreg": FunctionalUnitCoregistrationExtended,
-    "func_coreg_process_ref": FunctionalUnitCoregistrationQC,
+    "simple_reference": ReferenceAnnotation,
     "cell_type_local": CellTypeLocal,
     "cell_type_reference": CellTypeReference,
     "nucleus_detection": NucleusDetection,
